Merge "TIF: Be consistent with argument name for startRecording" into nyc-dev
am: 0751a83

* commit '0751a83a99dc4481533ed706a942b8bb9caf8834':
  TIF: Be consistent with argument name for startRecording

Change-Id: I27de469a898051caa8e7e41ca170c79ac0e7e3d1
diff --git a/media/java/android/media/tv/ITvInputManager.aidl b/media/java/android/media/tv/ITvInputManager.aidl
index 3ec7656..0d51b5b 100644
--- a/media/java/android/media/tv/ITvInputManager.aidl
+++ b/media/java/android/media/tv/ITvInputManager.aidl
@@ -87,7 +87,7 @@
     void timeShiftEnablePositionTracking(in IBinder sessionToken, boolean enable, int userId);
 
     // For the recording session
-    void startRecording(in IBinder sessionToken, in Uri programHint, int userId);
+    void startRecording(in IBinder sessionToken, in Uri programUri, int userId);
     void stopRecording(in IBinder sessionToken, int userId);
 
     // For TV input hardware binding
diff --git a/media/java/android/media/tv/ITvInputSession.aidl b/media/java/android/media/tv/ITvInputSession.aidl
index b1ce8d4..356ec3c 100644
--- a/media/java/android/media/tv/ITvInputSession.aidl
+++ b/media/java/android/media/tv/ITvInputSession.aidl
@@ -56,6 +56,6 @@
     void timeShiftEnablePositionTracking(boolean enable);
 
     // For the recording session
-    void startRecording(in Uri programHint);
+    void startRecording(in Uri programUri);
     void stopRecording();
 }
diff --git a/media/java/android/media/tv/ITvInputSessionWrapper.java b/media/java/android/media/tv/ITvInputSessionWrapper.java
index 56103ad..07cfbda 100644
--- a/media/java/android/media/tv/ITvInputSessionWrapper.java
+++ b/media/java/android/media/tv/ITvInputSessionWrapper.java
@@ -352,8 +352,8 @@
     }
 
     @Override
-    public void startRecording(@Nullable Uri programHint) {
-        mCaller.executeOrSendMessage(mCaller.obtainMessageO(DO_START_RECORDING, programHint));
+    public void startRecording(@Nullable Uri programUri) {
+        mCaller.executeOrSendMessage(mCaller.obtainMessageO(DO_START_RECORDING, programUri));
     }
 
     @Override
diff --git a/media/java/android/media/tv/TvRecordingClient.java b/media/java/android/media/tv/TvRecordingClient.java
index 2613376..5aadeb6 100644
--- a/media/java/android/media/tv/TvRecordingClient.java
+++ b/media/java/android/media/tv/TvRecordingClient.java
@@ -157,7 +157,7 @@
      *
      * <p>The application may supply the URI for a TV program for filling in program specific data
      * fields in the {@link android.media.tv.TvContract.RecordedPrograms} table.
-     * A non-null {@code programHint} implies the started recording should be of that specific
+     * A non-null {@code programUri} implies the started recording should be of that specific
      * program, whereas null {@code programUri} does not impose such a requirement and the
      * recording can span across multiple TV programs. In either case, the application must call
      * {@link TvRecordingClient#stopRecording()} to stop the recording.
diff --git a/services/core/java/com/android/server/tv/TvInputManagerService.java b/services/core/java/com/android/server/tv/TvInputManagerService.java
index e13ee13..b389cf5 100644
--- a/services/core/java/com/android/server/tv/TvInputManagerService.java
+++ b/services/core/java/com/android/server/tv/TvInputManagerService.java
@@ -1557,7 +1557,7 @@
         }
 
         @Override
-        public void startRecording(IBinder sessionToken, @Nullable Uri programHint, int userId) {
+        public void startRecording(IBinder sessionToken, @Nullable Uri programUri, int userId) {
             final int callingUid = Binder.getCallingUid();
             final int resolvedUserId = resolveCallingUserId(Binder.getCallingPid(), callingUid,
                     userId, "startRecording");
@@ -1566,7 +1566,7 @@
                 synchronized (mLock) {
                     try {
                         getSessionLocked(sessionToken, callingUid, resolvedUserId).startRecording(
-                                programHint);
+                                programUri);
                     } catch (RemoteException | SessionNotFoundException e) {
                         Slog.e(TAG, "error in startRecording", e);
                     }
diff --git a/media/java/android/media/tv/TvInputManager.java b/media/java/android/media/tv/TvInputManager.java
index 5c9d2b2..1d894e1 100644
--- a/media/java/android/media/tv/TvInputManager.java
+++ b/media/java/android/media/tv/TvInputManager.java
@@ -2093,16 +2093,16 @@
         /**
          * Starts TV program recording in the current recording session.
          *
          * @param programHint The URI for the TV program to record as a hint, built by
          *            {@link TvContract#buildProgramUri(long)}. Can be {@code null}.
          */
-        void startRecording(@Nullable Uri programHint) {
+        void startRecording(@Nullable Uri programUri) {
             if (mToken == null) {
                 Log.w(TAG, "The session has been already released");
                 return;
             }
             try {
-                mService.startRecording(mToken, programHint, mUserId);
+                mService.startRecording(mToken, programUri, mUserId);
             } catch (RemoteException e) {
                 throw e.rethrowFromSystemServer();
             }
@@ -2093,16 +2093,16 @@
          * Starts TV program recording in the current recording session.
          *
-         * @param programHint The URI for the TV program to record as a hint, built by
+         * @param programUri The URI for the TV program to record as a hint, built by
          *            {@link TvContract#buildProgramUri(long)}. Can be {@code null}.
          */
diff --git a/media/java/android/media/tv/TvInputService.java b/media/java/android/media/tv/TvInputService.java
index 7ae8da0..488b284 100644
--- a/media/java/android/media/tv/TvInputService.java
+++ b/media/java/android/media/tv/TvInputService.java
@@ -1695,8 +1695,8 @@
          *
          * <p>The application may supply the URI for a TV program for filling in program specific
          * data fields in the {@link android.media.tv.TvContract.RecordedPrograms} table.
          * A non-null {@code programHint} implies the started recording should be of that specific
          * program, whereas null {@code programHint} does not impose such a requirement and the
          * recording can span across multiple TV programs. In either case, the application must call
          * {@link TvRecordingClient#stopRecording()} to stop the recording.
          *
@@ -1761,8 +1761,8 @@
          * Calls {@link #onStartRecording(Uri)}.
          *
          */
-        void startRecording(@Nullable  Uri programHint) {
-            onStartRecording(programHint);
+        void startRecording(@Nullable  Uri programUri) {
+            onStartRecording(programUri);
         }
 
         /**
@@ -1695,8 +1695,8 @@
          * <p>The application may supply the URI for a TV program for filling in program specific
          * data fields in the {@link android.media.tv.TvContract.RecordedPrograms} table.
-         * A non-null {@code programHint} implies the started recording should be of that specific
-         * program, whereas null {@code programHint} does not impose such a requirement and the
+         * A non-null {@code programUri} implies the started recording should be of that specific
+         * program, whereas null {@code programUri} does not impose such a requirement and the
          * recording can span across multiple TV programs. In either case, the application must call
          * {@link TvRecordingClient#stopRecording()} to stop the recording.